# Contributing to ADP Python SDK

Thank you for your interest in contributing to the ADP Python SDK!

## How to Contribute

1. Fork the repository and create your branch from `main`.
2. Make your changes and ensure any new code is covered by tests.
3. Submit a pull request with a clear description of the change.

## License

By contributing, you agree that your contributions will be licensed under the [Apache License 2.0](LICENSE).

## License Header

Every source file must include the following header:

```
# Copyright 2026 Datastrato, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
```
